pub fn analyze(module: &Module, source: &str) -> Vec<Diagnostic>Expand description
Run all semantic checks on a parsed module and return any diagnostics.
pub fn analyze(module: &Module, source: &str) -> Vec<Diagnostic>Run all semantic checks on a parsed module and return any diagnostics.