analyze_with_external_refs

Function analyze_with_external_refs 

pub fn analyze_with_external_refs(
    module: &Module,
    source: &str,
    external_refs: &HashSet<String>,
) -> Vec<Diagnostic>
Run structural checks, accounting for cross-module references.

external_refs contains declaration names from this module that are referenced by other modules via qualified names (e.g. core/InputEvent). These names are excluded from unused-declaration warnings.