pub fn collect_declared_names(module: &Module) -> HashSet<String>Expand description
Collect all type names declared by a module (entities, external entities, values, enums, actors, contracts, variants).
Used by multi-file checking to determine which declarations from a target module could be the resolution target for unqualified references in an importing file.