Structs
Enums
Functions
- lex
- Tokenise
sourceinto a flat list of tokens, ending withEof. Whitespace and comments are skipped. The special comment-- allium: Nat the very start of the file is preserved as anIdenttoken followed by normal tokens (version detection happens in the parser by inspecting the raw source before tokenising).